"use client";

import type {
	IApiLoginReq,
	IApiLoginRes,
	IApiRegisterReq,
	IApiRegisterRes,
} from "@/interfaces/api.interface";
import type { IUserData } from "@/interfaces/userdata.interface";
import ApiRequest from "@/services/apiRequest";
import { useEncodedLocalStorage } from "@/services/localStorage";
import { createContext, useContext, useState } from "react";

const UserDataContext = createContext<IUserData | null>(null);
const [userData, setUserData] = useEncodedLocalStorage<IUserData | null>(
	"user_data",
	null,
);

//TODO Run register task
export async function doRegister(
	registerData: IApiRegisterReq,
): Promise<IApiRegisterRes | null> {
	console.trace(registerData);
	try {
		const ReqRes = await ApiRequest.standard.post.json<IApiRegisterReq, IApiRegisterRes>(
			"auth/signup",
			registerData,
		);
		console.trace(ReqRes.data);
		if (ReqRes.data.user) {
			setUserData(ReqRes.data.user);
		}
		ReqRes.data.message?.forEach((err) => console.warn(err));
		return ReqRes.data;
	} catch (error) {
		console.error("Error during registration:", error);
		return null;
	}
}

//TODO Run login task
export async function doLogin(loginData: IApiLoginReq) {
	try {
		const ReqRes = await ApiRequest.standard.post.json<IApiLoginReq, IApiLoginRes>(
			"auth/login",
			loginData,
		);
		console.trace(ReqRes.data);
		//if (ReqRes.data.user) {
		//  setUserData(ReqRes.data.user)
		//}
		ReqRes.data.message?.forEach((err) => console.warn(err));
		return ReqRes.data;
	} catch (err) {
		console.error("Error during login:", err);
		return null;
	}
}

//TODO Run disconnect task
export function doDisconnect() {
	if (typeof window !== "undefined") {
		window.localStorage.removeItem("sub");
		return true;
	}
	console.log(
		"Whut ? Why trying to remove an item from the localStorage when runner in SSR ?",
	);
	return false;
}

//TODO Run update user data
